@@ -26,8 +26,8 @@
 */
 
 
-#include <kpMainWindow.h>
-#include <kpMainWindowPrivate.h>
+#include "mainWindow/kpMainWindow.h"
+#include "kpMainWindowPrivate.h"
 
 #include <QActionGroup>
 #include <qlist.h>
@@ -37,40 +37,39 @@
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <kdebug.h>
-#include <kglobal.h>
 #include <klocale.h>
 
-#include <kpColorToolBar.h>
-#include <kpCommandHistory.h>
-#include <kpDocument.h>
-#include <kpImageSelectionTransparency.h>
-#include <kpTool.h>
-#include <kpToolAction.h>
-#include <kpToolBrush.h>
-#include <kpToolColorEraser.h>
-#include <kpToolColorPicker.h>
-#include <kpToolCurve.h>
-#include <kpToolEllipticalSelection.h>
-#include <kpToolEllipse.h>
-#include <kpToolEraser.h>
-#include <kpToolFloodFill.h>
-#include <kpToolFreeFormSelection.h>
-#include <kpToolLine.h>
-#include <kpToolPen.h>
-#include <kpToolPolygon.h>
-#include <kpToolPolyline.h>
-#include <kpToolRectangle.h>
-#include <kpToolRectSelection.h>
-#include <kpToolRoundedRectangle.h>
-#include <kpToolSelectionEnvironment.h>
-#include <kpToolSpraycan.h>
-#include <kpToolText.h>
-#include <kpToolToolBar.h>
-#include <kpToolWidgetOpaqueOrTransparent.h>
-#include <kpToolZoom.h>
-#include <kpTransformResizeScaleCommand.h>
-#include <kpViewScrollableContainer.h>
-#include <kpZoomedView.h>
+#include "widgets/toolbars/kpColorToolBar.h"
+#include "commands/kpCommandHistory.h"
+#include "document/kpDocument.h"
+#include "layers/selections/image/kpImageSelectionTransparency.h"
+#include "tools/kpTool.h"
+#include "tools/kpToolAction.h"
+#include "tools/flow/kpToolBrush.h"
+#include "tools/flow/kpToolColorEraser.h"
+#include "tools/kpToolColorPicker.h"
+#include "tools/polygonal/kpToolCurve.h"
+#include "tools/selection/image/kpToolEllipticalSelection.h"
+#include "tools/rectangular/kpToolEllipse.h"
+#include "tools/flow/kpToolEraser.h"
+#include "tools/kpToolFloodFill.h"
+#include "tools/selection/image/kpToolFreeFormSelection.h"
+#include "tools/polygonal/kpToolLine.h"
+#include "tools/flow/kpToolPen.h"
+#include "tools/polygonal/kpToolPolygon.h"
+#include "tools/polygonal/kpToolPolyline.h"
+#include "tools/rectangular/kpToolRectangle.h"
+#include "tools/selection/image/kpToolRectSelection.h"
+#include "tools/rectangular/kpToolRoundedRectangle.h"
+#include "environments/tools/selection/kpToolSelectionEnvironment.h"
+#include "tools/flow/kpToolSpraycan.h"
+#include "tools/selection/text/kpToolText.h"
+#include "widgets/toolbars/kpToolToolBar.h"
+#include "widgets/toolbars/options/kpToolWidgetOpaqueOrTransparent.h"
+#include "tools/kpToolZoom.h"
+#include "commands/imagelib/transforms/kpTransformResizeScaleCommand.h"
+#include "kpViewScrollableContainer.h"
+#include "views/kpZoomedView.h"
 
 //---------------------------------------------------------------------
 
@@ -134,25 +133,25 @@ void kpMainWindow::setupToolActions ()
 
     d->actionPrevToolOptionGroup1 = ac->addAction ("prev_tool_option_group_1");
     d->actionPrevToolOptionGroup1->setText (i18n ("Previous Tool Option (Group #1)"));
-    d->actionPrevToolOptionGroup1->setShortcuts (kpTool::shortcutForKey (Qt::Key_1));
+    ac->setDefaultShortcuts (d->actionPrevToolOptionGroup1, kpTool::shortcutForKey (Qt::Key_1));
     connect (d->actionPrevToolOptionGroup1, SIGNAL (triggered (bool)),
         SLOT (slotActionPrevToolOptionGroup1 ()));
 
     d->actionNextToolOptionGroup1 = ac->addAction ("next_tool_option_group_1");
     d->actionNextToolOptionGroup1->setText (i18n ("Next Tool Option (Group #1)"));
-    d->actionNextToolOptionGroup1->setShortcuts (kpTool::shortcutForKey (Qt::Key_2));
+    ac->setDefaultShortcuts (d->actionNextToolOptionGroup1, kpTool::shortcutForKey (Qt::Key_2));
     connect (d->actionNextToolOptionGroup1, SIGNAL (triggered (bool)),
         SLOT (slotActionNextToolOptionGroup1 ()));
 
     d->actionPrevToolOptionGroup2 = ac->addAction ("prev_tool_option_group_2");
     d->actionPrevToolOptionGroup2->setText (i18n ("Previous Tool Option (Group #2)"));
-    d->actionPrevToolOptionGroup2->setShortcuts (kpTool::shortcutForKey (Qt::Key_3));
+    ac->setDefaultShortcuts (d->actionPrevToolOptionGroup2, kpTool::shortcutForKey (Qt::Key_3));
     connect (d->actionPrevToolOptionGroup2, SIGNAL (triggered (bool)),
         SLOT (slotActionPrevToolOptionGroup2 ()));
 
     d->actionNextToolOptionGroup2 = ac->addAction ("next_tool_option_group_2");
     d->actionNextToolOptionGroup2->setText (i18n ("Next Tool Option (Group #2)"));
-    d->actionNextToolOptionGroup2->setShortcuts (kpTool::shortcutForKey (Qt::Key_4));
+    ac->setDefaultShortcuts (d->actionNextToolOptionGroup2, kpTool::shortcutForKey (Qt::Key_4));
     connect (d->actionNextToolOptionGroup2, SIGNAL (triggered (bool)),
         SLOT (slotActionNextToolOptionGroup2 ()));
 
@@ -492,7 +491,7 @@ void kpMainWindow::slotToolSelected (kpTool *tool)
 // private
 void kpMainWindow::readLastTool ()
 {
-    KConfigGroup cfg (KGlobal::config (), kpSettingsGroupTools);
+    KConfigGroup cfg (KSharedConfig::openConfig (), kpSettingsGroupTools);
 
     d->lastToolNumber = cfg.readEntry (kpSettingLastTool, -1);
 }
@@ -526,7 +525,7 @@ void kpMainWindow::saveLastTool ()
         return;
 
 
-    KConfigGroup cfg (KGlobal::config (), kpSettingsGroupTools);
+    KConfigGroup cfg (KSharedConfig::openConfig (), kpSettingsGroupTools);
 
     cfg.writeEntry (kpSettingLastTool, number);
     cfg.sync ();
